Browser Support - Tabler - Premium and Open Source dashboard template with responsive and high quality UI.

## Documentation

# Browser Support

As of this latest release, Tabler has launched many new features that may not be compatible with all browsers, especially older ones.

For instance, Tabler no longer uses vendor prefixes in styles that are known to have some compatibility issues except for a few parts. Tabler also supports new features such as CSS grid, object fit, and sticky positioning which is not yet supported on all browsers. In short, Tabler supports all the latest supported browsers with only partial support for Internet Explorer.

## Supported Browsers

Browser | Version
--- | ---
Edge | last 3 versions
Firefox | last 3 versions, ESR
Chrome | last 3 versions
Safari | last 3 versions
Opera | last 3 versions
Electron | last 3 versions
Brave | last 3 versions
Vivaldi | last 3 versions